/**
 * JASMINe
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: NotificationSetting.java 4798 2009-08-07 12:30:47Z alitokmen $
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.monitoring.eos.notification.service.exchange;

import java.util.ArrayList;
import java.util.List;

public class NotificationSetting {

    /**
     * The name of the rule associated with the action.
     */
    private String rule;

    /**
     * The level associated to the rule. The default value is "Info".
     */
    private LevelSetting level = new LevelSetting();

    /**
     * The name of the action.
     */
    private List<String> actionList = null;

    /**
     * Whether the notification needs to be acknowledge before executing actions
     * or not. Default is false.
     */
    private boolean synchronize;

    /**
     * Acknowledge action name.
     */
    private String acknowledgeActionName;

    /**
     * How many hours the notification will be displayed after being acknowledged,
     * or if not synchronized after the notification date.
     */
    private int keepDisplayed;

    /**
     * Default empty constructor for the binding with the Flex object.
     */
    public NotificationSetting() {
        this.actionList = new ArrayList<String>();
    }

    /**
     * This constructor allow to set the rule, the action names and the level.
     *
     * @param rule the rule name to set.
     * @param action the action name.
     * @param level the level to set.
     */
    public NotificationSetting(final String rule, final List<String> action, final LevelSetting level, final boolean synchronize) {
        this.rule = rule;
        this.actionList = action;
        this.level = level;
        this.synchronize = synchronize;
    }

    /**
     * @return the rule name.
     */
    public String getRule() {
        return rule;
    }

    /**
     * @param rule the rule name to set.
     */
    public void setRule(final String rule) {
        this.rule = rule;
    }

    /**
     * @return the action name.
     */
    public List<String> getAction() {
        return actionList;
    }

    /**
     * @param action the action name to set.
     */
    public void setAction(final List<String> action) {
        this.actionList = action;
    }

    /**
     * @return the level
     */
    public LevelSetting getLevel() {
        return level;
    }

    /**
     * @param level the level to set
     */
    public void setLevel(final LevelSetting level) {
        this.level = level;
    }

    /**
     * Add the specified action to the list.
     *
     * @param action the action to add to the list.
     */
    public void addAction(final String action) {
        this.actionList.add(action);
    }

    /**
     * @return the synchronize
     */
    public boolean isSynchronize() {
        return synchronize;
    }

    /**
     * @param synchronize the synchronize to set
     */
    public void setSynchronize(final boolean synchronize) {
        this.synchronize = synchronize;
    }

    /**
     * @return the acknowledgeActionName
     */
    public String getAcknowledgeActionName() {
        return acknowledgeActionName;
    }

    /**
     * @param acknowledgeActionName the acknowledgeActionName to set
     */
    public void setAcknowledgeActionName(final String acknowledgeActionName) {
        this.acknowledgeActionName = acknowledgeActionName;
    }

    /**
     * @return the keepDisplayed
     */
    public int getKeepDisplayed() {
        return keepDisplayed;
    }

    /**
     * @param keepDisplayed the keepDisplayed to set
     */
    public void setKeepDisplayed(final int keepDisplayed) {
        this.keepDisplayed = keepDisplayed;
    }

}
