/**
 * JASMINe
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * $Id: NotificationEventManager.java 4836 2009-08-09 20:41:41Z renaultgu $
 */
package org.ow2.jasmine.monitoring.eos.notification.service.jms;

import java.util.ArrayList;
import java.util.List;

import org.ow2.jasmine.event.beans.JasmineEventNotification;
import org.ow2.jasmine.monitoring.eos.common.EventManager;
import org.ow2.util.log.Log;
import org.ow2.util.log.LogFactory;

/**
 * @author Jean-Pierre Poutcheu
 */
public class NotificationEventManager implements EventManager<JasmineEventNotification>{

    /**
     * Logger.
     */
   private static Log logger = LogFactory.getLog(NotificationEventManager.class);

    /**
     * list of waiting notifications.
     */
    private List < JasmineEventNotification > events = null;

    /**
     * Unique instance of the manager.
     */
    private static NotificationEventManager instance = null;

    /**
     * Local constructor of the manager. Initialize the list.
     */
    private NotificationEventManager() {
        this.events = new ArrayList <JasmineEventNotification> ();
    }

    /**
     * Get the unique instance of the manager.
     * @return instance the manager instance.
     */
    public static NotificationEventManager getInstance() {
        if (instance == null) {
            instance = new NotificationEventManager();
        }
        return instance;
    }

    /**
     * Add an notification event in the list.
     *
     * @param event the event to add.
     */
    public void add(final JasmineEventNotification event) {
        logger.debug("Received notification {0}", event.getId());
        this.events.add(event);
    }

    /**
     * Clear the list once treated.
     */
    private void clear() {
        this.events.removeAll(this.events);
    }

    /**
     * Get the entire queue of waiting events.
     *
     * @return the queue of events.
     */
    public List<JasmineEventNotification> getAll() {
        try {
            logger.debug("getting all");

            List<JasmineEventNotification> l = new ArrayList<JasmineEventNotification>();
            l.addAll(this.events);

            logger.debug("Number of datas the manager owns : {0}", this.events.size());

            return l;
        } finally {
            this.clear();
        }
    }

}

